%global modname ipykernel
%global _description \
This package provides the IPython kernel for Jupyter.

%bcond_without bootstrap

%if %{with bootstrap}
%bcond_with tests
%bcond_with doc
%else
%bcond_without tests
%bcond_without doc
%endif

Summary:        IPython Kernel for Jupyter
Name:           python-%{modname}
Version:        6.29.3
Release:        1%{?dist}
License:        BSD-3-Clause
URL:            https://github.com/ipython/%{modname}
Source0:        %{url}/releases/download/v%{version}/%{modname}-%{version}.tar.gz

Patch0001:      https://github.com/ipython/ipykernel/commit/a7d66a.patch

BuildRequires:  python3-devel
BuildArch:      noarch

%description %{_description}

%package -n python%{python3_pkgversion}-%{modname}
Summary:        IPython Kernel for Jupyter
Requires:       python-jupyter-filesystem

%if %{with doc}
BuildRequires:  make python3-pydata-sphinx-theme
BuildRequires:  python3-sphinx python3-myst-parser
BuildRequires:  python3-sphinx-autodoc-typehints python3-sphinxcontrib-github-alt
BuildRequires:  python%{python3_pkgversion}-docs python-jupyter-client-doc
BuildRequires:  python%{python3_pkgversion}-ipython-doc
%endif

Recommends:     python%{python3_pkgversion}-matplotlib
Recommends:     python%{python3_pkgversion}-numpy
Recommends:     python%{python3_pkgversion}-pandas
Recommends:     python%{python3_pkgversion}-scipy
Recommends:     python%{python3_pkgversion}-pillow

%description -n python%{python3_pkgversion}-%{modname} %{_description}

%if %{with doc}
%package doc
Summary:        Documentation for %{name}
Requires:       python%{python3_pkgversion}-docs
Requires:       python%{python3_pkgversion}-ipython-doc
Requires:       python-jupyter-client-doc

%description    doc
This package contains the documentation of %{name}.
%endif

%prep
%autosetup -p1 -n %{modname}-%{version}

sed -i '/"debugpy/d' pyproject.toml

%if %{with doc}
sed -e "s|\(('https://docs.python.org/3/', \)None)|\1'/usr/share/doc/python3-docs/html/objects.inv')|" \
    -e "s|\(('https://ipython.readthedocs.io/en/latest', \)None)|\1'/usr/share/doc/python3-ipython-doc/html/objects.inv')|" \
    -e "s|\(('https://jupyter.readthedocs.io/en/latest', \)None)|\1'/usr/share/doc/python-jupyter-client/html/objects.inv')|" \
    -i docs/conf.py
%endif

%generate_buildrequires
%pyproject_buildrequires %{?with_tests:-x test}

%build
%pyproject_wheel

%if %{with doc}
%make_build -C docs html
%endif

%install
%pyproject_install
%pyproject_save_files %{modname} %{modname}_launcher
%if %{with doc}
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -fpavr docs/_build/html %{buildroot}%{_docdir}/%{name}
rm %{buildroot}%{_docdir}/%{name}/html/.buildinfo
%endif

%{python3} -m ipykernel install --prefix %{buildroot}%{_prefix}
ls %{buildroot}%{_datadir}/jupyter/kernels/python3/
cat %{buildroot}%{_datadir}/jupyter/kernels/python3/kernel.json


%check
%if %{with tests}
%pytest -Wdefault
%endif


%files -n python%{python3_pkgversion}-%{modname}
%license LICENSE
%doc CONTRIBUTING.md README.md
%{python3_sitelib}/%{modname}
%pycached %{python3_sitelib}/%{modname}_launcher.py
%{python3_sitelib}/%{modname}*.dist-info/
%{_datadir}/jupyter/kernels/python3

%if %{with doc}
%files doc
%doc %{_docdir}/%{name}/html
%endif


%changelog
* Thu Jun 13 2024 Shuo Wang <abushwang@tencent.com> - 6.29.3-1
- initial build
